Enum style::values::computed::font::FamilyNameSyntax
[−]
[src]
pub enum FamilyNameSyntax {
Quoted,
Identifiers(String),
}Font family names must either be given quoted as strings, or unquoted as a sequence of one or more identifiers.
Variants
QuotedThe family name was specified in a quoted form, e.g. "Font Name" or 'Font Name'.
Identifiers(String)The family name was specified in an unquoted form as a sequence of
identifiers. The String is the serialization of the sequence of
identifiers.