Struct style::values::computed::font::FontSize
[−]
[src]
pub struct FontSize {
pub size: NonNegativeLength,
pub keyword_info: Option<KeywordInfo>,
}The computed value of font-size
Fields
size: NonNegativeLength
The size.
keyword_info: Option<KeywordInfo>
If derived from a keyword, the keyword and additional transformations applied to it
Methods
impl FontSize[src]
pub fn size(self) -> Au[src]
The actual computed font size.
pub fn medium() -> Self[src]
Get default value of font size.
pub fn cascade_inherit_font_size(context: &mut Context)[src]
FIXME(emilio): This is very complex. Also, it should move to StyleBuilder.
pub fn cascade_initial_font_size(context: &mut Context)[src]
Cascade the initial value for the font-size property.
FIXME(emilio): This is the only function that is outside of the
StyleBuilder, and should really move inside!
Can we move the font stuff there?